@@ -94,7 +94,7 @@ static rc_t print_fastq_1_read( join_stats * stats,
    
     if ( rec -> read . len != rec -> quality . len )
     {
-        ErrMsg( "row #%ld : READ.len(%u) != QUALITY.len(%u)\n", rec -> row_id, rec -> read . len, rec -> quality . len );
+        ErrMsg( "row #%ld : READ.len(%u) != QUALITY.len(%u) (A)\n", rec -> row_id, rec -> read . len, rec -> quality . len );
         stats -> reads_invalid++;
         if ( jo -> terminate_on_invalid )
             return SILENT_RC( rcApp, rcNoTarg, rcReading, rcItem, rcInvalid );
@@ -133,7 +133,7 @@ static rc_t print_fastq_n_reads_split( join_stats * stats,
     
     if ( rec -> read . len != rec -> quality . len )
     {
-        ErrMsg( "row #%ld : READ.len(%u) != QUALITY.len(%u)\n", rec -> row_id, rec -> read . len, rec -> quality . len );
+        ErrMsg( "row #%ld : READ.len(%u) != QUALITY.len(%u) (B)\n", rec -> row_id, rec -> read . len, rec -> quality . len );
         stats -> reads_invalid++;
         if ( jo -> terminate_on_invalid )
             return SILENT_RC( rcApp, rcNoTarg, rcReading, rcItem, rcInvalid );
@@ -144,7 +144,7 @@ static rc_t print_fastq_n_reads_split( join_stats * stats,
 
     if ( rec -> read . len != read_len_sum )
     {
-        ErrMsg( "row #%ld : READ.len(%u) != sum(READ_LEN)(%u)\n", rec -> row_id, rec -> read . len, read_len_sum );
+        ErrMsg( "row #%ld : READ.len(%u) != sum(READ_LEN)(%u) (C)\n", rec -> row_id, rec -> read . len, read_len_sum );
         stats -> reads_invalid++;
         if ( jo -> terminate_on_invalid )
             return SILENT_RC( rcApp, rcNoTarg, rcReading, rcItem, rcInvalid );
@@ -203,7 +203,7 @@ static rc_t print_fastq_n_reads_split_file( join_stats * stats,
     
     if ( rec -> read . len != rec -> quality . len )
     {
-        ErrMsg( "row #%ld : READ.len(%u) != QUALITY.len(%u)\n", rec -> row_id, rec -> read . len, rec -> quality . len );
+        ErrMsg( "row #%ld : READ.len(%u) != QUALITY.len(%u) (D)\n", rec -> row_id, rec -> read . len, rec -> quality . len );
         stats -> reads_invalid++;
         if ( jo -> terminate_on_invalid )
             return SILENT_RC( rcApp, rcNoTarg, rcReading, rcItem, rcInvalid );
@@ -214,7 +214,7 @@ static rc_t print_fastq_n_reads_split_file( join_stats * stats,
 
     if ( rec -> read . len != read_len_sum )
     {
-        ErrMsg( "row #%ld : READ.len(%u) != sum(READ_LEN)(%u)\n", rec -> row_id, rec -> read . len, read_len_sum );
+        ErrMsg( "row #%ld : READ.len(%u) != sum(READ_LEN)(%u) (E)\n", rec -> row_id, rec -> read . len, read_len_sum );
         stats -> reads_invalid++;
         if ( jo -> terminate_on_invalid )
             return SILENT_RC( rcApp, rcNoTarg, rcReading, rcItem, rcInvalid );
@@ -270,12 +270,13 @@ static rc_t print_fastq_n_reads_split_3( join_stats * stats,
     uint32_t read_id_0 = 0;
     uint32_t write_id_1 = 1;
     uint32_t valid_reads = 0;
+    uint32_t valid_bio_reads = 0;
     uint32_t offset = 0;
     uint32_t read_len_sum = 0;
     
     if ( rec -> read . len != rec -> quality . len )
     {
-        ErrMsg( "row #%ld : READ.len(%u) != QUALITY.len(%u)\n", rec -> row_id, rec -> read . len, rec -> quality . len );
+        ErrMsg( "row #%ld : READ.len(%u) != QUALITY.len(%u) (F)\n", rec -> row_id, rec -> read . len, rec -> quality . len );
         stats -> reads_invalid++;
         if ( jo -> terminate_on_invalid )
             return SILENT_RC( rcApp, rcNoTarg, rcReading, rcItem, rcInvalid );
@@ -285,13 +286,25 @@ static rc_t print_fastq_n_reads_split_3( join_stats * stats,
     {
         read_len_sum += rec -> read_len[ read_id_0 ];
         if ( rec -> read_len[ read_id_0 ] > 0 )
+        {
             valid_reads++;
+            if ( ( rec -> read_type[ read_id_0 ] & READ_TYPE_BIOLOGICAL ) == READ_TYPE_BIOLOGICAL )
+            {
+                if ( jo -> min_read_len > 0 )
+                {
+                    if ( rec -> read_len[ read_id_0 ] >= jo -> min_read_len )
+                        valid_bio_reads++;    
+                }
+                else
+                    valid_bio_reads++;
+            }
+        }
         read_id_0++;
     }
 
     if ( rec -> read . len != read_len_sum )
     {
-        ErrMsg( "row #%ld : READ.len(%u) != sum(READ_LEN)(%u)\n", rec -> row_id, rec -> read . len, read_len_sum );
+        ErrMsg( "row #%ld : READ.len(%u) != sum(READ_LEN)(%u) (G)\n", rec -> row_id, rec -> read . len, read_len_sum );
         stats -> reads_invalid++;
         if ( jo -> terminate_on_invalid )
             return SILENT_RC( rcApp, rcNoTarg, rcReading, rcItem, rcInvalid );
@@ -318,6 +331,9 @@ static rc_t print_fastq_n_reads_split_3( join_stats * stats,
                     Q . size = rec -> read_len[ read_id_0 ];
                     Q . len  = ( uint32_t )Q . size;
                 
+                    if ( valid_bio_reads < 2 )
+                        write_id_1 = 0;
+
                     rc = join_results_print_fastq_v1( results,
                                                       rec -> row_id,
                                                       write_id_1,
@@ -548,6 +564,8 @@ typedef struct join_thread_data
     join_stats stats;
 
     KDirectory * dir;
+    const VDBManager * vdb_mgr;
+
     const char * accession_path;
     const char * accession_short;
     const char * tbl_name;
@@ -584,7 +602,8 @@ static rc_t CC cmn_thread_func( const KThread *self, void *data )
     
     if ( rc == 0 && results != NULL )
     {
-        cmn_params cp = { jtd -> dir, jtd -> accession_path, jtd -> first_row, jtd -> row_count, jtd -> cur_cache };
+        cmn_params cp = { jtd -> dir, jtd -> vdb_mgr, 
+                          jtd -> accession_path, jtd -> first_row, jtd -> row_count, jtd -> cur_cache };
         switch( jtd -> fmt )
         {
             case ft_whole_spot       : rc = perform_whole_spot_join( &cp,
@@ -623,13 +642,14 @@ static rc_t CC cmn_thread_func( const KThread *self, void *data )
 }
 
 static rc_t extract_sra_row_count( KDirectory * dir,
+                                   const VDBManager * vdb_mgr,
                                    const char * accession_path,
                                    const char * tbl_name,
                                    size_t cur_cache,
                                    uint64_t * res )
 {
-    cmn_params cp = { dir, accession_path, 0, 0, cur_cache };
-    struct fastq_sra_iter * iter;
+    cmn_params cp = { dir, vdb_mgr, accession_path, 0, 0, cur_cache }; /* helper.h */
+    struct fastq_sra_iter * iter; 
     fastq_iter_opt opt = { false, false, false };
     rc_t rc = make_fastq_sra_iter( &cp, opt, tbl_name, &iter ); /* fastq_iter.c */
     if ( rc == 0 )
@@ -641,11 +661,12 @@ static rc_t extract_sra_row_count( KDirectory * dir,
 }
 
 rc_t execute_tbl_join( KDirectory * dir,
+                    const VDBManager * vdb_mgr,
                     const char * accession_path,
                     const char * accession_short,
                     join_stats * stats,
                     const char * tbl_name,
-                    const tmp_id * tmp_id,
+                    const struct temp_dir * temp_dir,
                     struct temp_registry * registry,
                     size_t cur_cache,
                     size_t buf_size,
@@ -657,20 +678,24 @@ rc_t execute_tbl_join( KDirectory * dir,
     rc_t rc = 0;
     
     if ( show_progress )
+    {
+        KOutHandlerSetStdErr();
         rc = KOutMsg( "join   :" );
-
+        KOutHandlerSetStdOut();
+    }
+    
     if ( rc == 0 )
     {
         uint64_t row_count = 0;
-        rc = extract_sra_row_count( dir, accession_path, tbl_name, cur_cache, &row_count ); /* above */
+        rc = extract_sra_row_count( dir, vdb_mgr, accession_path, tbl_name, cur_cache, &row_count ); /* above */
         if ( rc == 0 && row_count > 0 )
         {
             bool name_column_present;
 
             if ( tbl_name == NULL )
-                rc = cmn_check_tbl_column( dir, accession_path, "NAME", &name_column_present );
+                rc = cmn_check_tbl_column( dir, vdb_mgr, accession_path, "NAME", &name_column_present );
             else
-                rc = cmn_check_db_column( dir, accession_path, tbl_name, "NAME", &name_column_present );
+                rc = cmn_check_db_column( dir, vdb_mgr, accession_path, tbl_name, "NAME", &name_column_present );
             
             if ( rc == 0 )
             {
@@ -710,6 +735,7 @@ rc_t execute_tbl_join( KDirectory * dir,
                     if ( jtd != NULL )
                     {
                         jtd -> dir              = dir;
+                        jtd -> vdb_mgr          = vdb_mgr;
                         jtd -> accession_path   = accession_path;
                         jtd -> accession_short  = accession_short;
                         jtd -> tbl_name         = tbl_name;
@@ -722,8 +748,8 @@ rc_t execute_tbl_join( KDirectory * dir,
                         jtd -> fmt              = fmt;
                         jtd -> join_options     = &corrected_join_options;
 
-                        rc = make_joined_filename( jtd -> part_file, sizeof jtd -> part_file,
-                                    accession_short, tmp_id, thread_id ); /* helper.c */
+                        rc = make_joined_filename( temp_dir, jtd -> part_file, sizeof jtd -> part_file,
+                                    accession_short, thread_id ); /* temp_dir.c */
 
                         if ( rc == 0 )
                         {
