@@ -23,6 +23,7 @@ ORIGINAL_CMD="$0 $@"
 IMPORT_TAG="import"
 DELITE_TAG="delite"
 EXPORT_TAG="export"
+TEST_TAG="test"
 STATUS_TAG="status"
 
 ACCESSION_TAG="--accession"
@@ -71,6 +72,7 @@ Where :
                       working directory
              $DELITE_TAG - script will perform DELITE on database content
              $EXPORT_TAG - script will create 'delited' KAR archive
+               $TEST_TAG - script will test 'exported' KAR archive
              $STATUS_TAG - script will report some status, or whatever.
 
 Options:
@@ -112,6 +114,8 @@ case $ACTION in
         ;;
     $EXPORT_TAG)
         ;;
+    $TEST_TAG)
+        ;;
     $STATUS_TAG)
         ;;
     *)
@@ -316,8 +320,6 @@ diff-exclude RIGHT_SOFT_CLIP
 # USE_OWN_TEMPDIR=1
 ### That is for docker, and please do not modify it by yourself
 # DELITE_GUID=
-### That is for new version of make-read-filter
-DELITE_REJECT_VDBCACHE=1
 
 EOF
     else
@@ -566,9 +568,12 @@ set_resolve_set_dir_values ()
     fi
 
     TARGET_DIR=$TDVAL
-    DATABASE_DIR=$TARGET_DIR/orig
-    NEW_KAR_FILE=$TARGET_DIR/new.kar
-    ORIG_KAR_FILE=$TARGET_DIR/orig.kar
+    DATABASE_DIR=$TARGET_DIR/work
+    DATABASE_CACHE_DIR=$TARGET_DIR/work.vch
+    NEW_KAR_FILE=$TARGET_DIR/out
+    NEW_CACHE_FILE=$TARGET_DIR/out.vch
+    ORIG_KAR_FILE=$TARGET_DIR/in
+    ORIG_CACHE_FILE=$TARGET_DIR/in.vch
     STATUS_FILE=$TARGET_DIR/.status.txt
     VDBCFG_NAME=vdbconfig.kfg
     VDBCFG_FILE=$TARGET_DIR/$VDBCFG_NAME
@@ -581,6 +586,15 @@ set_resolve_set_dir_values
 export NCBI_SETTINGS=/
 export VDB_CONFIG=$VDBCFG_NAME
 
+if [ -z "$DELITE_GUID" ]
+then
+    UUIDGEN=$( which uuidgen )
+    if [ $? -eq 0 ]
+    then
+        DELITE_GUID=$( uuidgen )
+    fi
+fi
+
 ###############################################################################################
 ##  There will be description of status file, which is quite secret file
 ##  ...
@@ -717,13 +731,13 @@ import_proc ()
 /sra/quality_type = "raw_scores"
 EOF
 
-###
-##  In the case of AWS, we needed GUID for correct work
-#
-if [ -n "$DELITE_GUID" ]
-then
-    echo /LIBS/GUID = \"$DELITE_GUID\" >>$VDBCFG_FILE
-fi
+    ###
+    ##  In the case of AWS, we needed GUID for correct work
+    #
+    if [ -n "$DELITE_GUID" ]
+    then
+        echo /LIBS/GUID = \"$DELITE_GUID\" >>$VDBCFG_FILE
+    fi
 
     info_msg Changing directory to \'$TARGET_DIR\'
     cd $TARGET_DIR
@@ -742,24 +756,6 @@ fi
         dpec__ 105; err_exit can not stat file \'$TOUTF\'
     fi
 
-    if [ -n "$DELITE_REJECT_VDBCACHE" ]
-    then
-        VCH=$( ls ${TOUTD}/*.vdbcache 2>/dev/null )
-        if [ -n "$VCH" ]
-        then
-cat <<EOF >&2
-
-WARNING: This run will not be processed because current make-read-filter
-utility does not support vdbcache files. Please, try to DELITE that run
-later, when new version of make-read-filter utility will be available.
-Thank You for understanding.
-
-EOF
-
-            dpec__ 80; err_exit can not process VDBCACHE file \'$TOUTF\'
-        fi
-    fi
-
     info_msg Read `stat --format="%s" $TOUTF` bytes to \'$TARGET_DIR/$TOUTF\'
 
     dpec__ 61; exec_cmd_exit ln -s $TOUTF $ORIG_KAR_FILE
@@ -772,6 +768,14 @@ EOF
 
     dpec__ 62; exec_cmd_exit $ICMD --extract $ORIG_KAR_FILE --directory $DATABASE_DIR
 
+    TOUTC=${TOUTF}.vdbcache
+    if [ -f "$TOUTC" ]
+    then
+        info_msg "Found .VDBCACHE file"
+        dpec__ 61; exec_cmd_exit ln -s $TOUTC $ORIG_CACHE_FILE
+        dpec__ 62; exec_cmd_exit $ICMD --extract $ORIG_CACHE_FILE --directory $DATABASE_CACHE_DIR
+    fi
+
     ## Checking if it is colorspace run
     check_rejected_run_exit
 
@@ -797,11 +801,25 @@ check_ready_for_delite ()
         dpec__ 105; err_exit can not stat directory \'$SCHEMA_VAL\'
     fi
 
+    SCHEMA_DIR=`cd $SCHEMA_VAL; pwd`
+    if [ -z "$SCHEMA_DIR" ]
+    then
+        dpec__ 105; err_exit can not resolve directory \'$SCHEMA_VAL\'
+    fi
+
     if [ ! -d "$DATABASE_DIR" ]
     then
         dpec__ 105; err_exit can not stat database \'$DATABASE_DIR\'
     fi
 
+    if [ -e "$ORIG_CACHE_FILE" ]
+    then
+        if [ ! -d "$DATABASE_CACHE_DIR" ]
+        then
+            dpec__ 105; err_exit can not stat database VDBCACHE \'$DATABASE_CACHE_DIR\'
+        fi
+    fi
+
     if [ ! -f "$STATUS_FILE" ]
     then
         dpec__ 105; err_exit can not stat status file
@@ -993,7 +1011,7 @@ modify_object ()
     if [ -n "$NEW_SCHEMA" ]
     then
         info_msg subst $OLD_SCHEMA to $NEW_SCHEMA
-        dpec__ 63; exec_cmd_exit $KARMETA_BIN --spath $SCHEMA_VAL --updschema schema=\'$NEW_SCHEMA\' $M2D
+        dpec__ 63; exec_cmd_exit $KARMETA_BIN --spath $SCHEMA_DIR --updschema schema=\'$NEW_SCHEMA\' $M2D
     else
         warn_msg no subst found for $OLD_SCHEMA
     fi
@@ -1225,22 +1243,14 @@ check_read_and_quality_len ()
 
 test_kar ()
 {
-    F2T=$1
-
-    if [ -n "$SKIPTEST_VAL" ]
-    then
-        warn_msg skipping tests for \'$F2T\' ...
-        return
-    fi
-
-    check_read_and_quality_len $F2T
+    check_read_and_quality_len $NEW_KAR_FILE
 
     if [ ! -f $ORIG_KAR_FILE ]
     then
-        dpec__ 105; err_exit SKIPPING DIFF TESTS for \'$F2T\', can not stat original KAR file \'$ORIG_KAR_FILE\'
+        dpec__ 105; err_exit SKIPPING DIFF TESTS for \'$NEW_KAR_FILE\', can not stat original KAR file \'$ORIG_KAR_FILE\'
     fi
 
-    exec_cmd $VDBVALIDATE_BIN -x $F2T
+    exec_cmd $VDBVALIDATE_BIN -x $NEW_KAR_FILE
     if [ $? -ne 0 ]
     then
         warn_msg vdb-validate step failed, checking original KAR file
@@ -1253,7 +1263,7 @@ test_kar ()
         fi
     fi
 
-    TCMD="$VDBDIFF_BIN $ORIG_KAR_FILE $F2T -i"
+    TCMD="$VDBDIFF_BIN $ORIG_KAR_FILE $NEW_KAR_FILE -c -i"
 
     TDC="$DIFFEXCLUDE"
 
@@ -1288,18 +1298,32 @@ test_kar ()
     dpec__ 68; exec_cmd_exit $TCMD
 }
 
-kar_new ()
+check_force_remove_old_kar ()
 {
-    if [ -f "$NEW_KAR_FILE" ]
+    F2R=$1
+    MSS=$2
+
+    if [ -z "$MSS" ]
+    then
+        MSS="KAR"
+    fi
+
+    if [ -f "$F2R" ]
     then
         if [ -n "$FORCE_VAL" ]
         then
-            info_msg forcing to remove odl KAR file \'$NEW_KAR_FILE\'
-            dpec__ 107; exec_cmd_exit rm $NEW_KAR_FILE
+            info_msg forcing to remove old $MSS file \'$F2R\'
+            dpec__ 107; exec_cmd_exit rm "$F2R"
         else
-            dpec__ 106; err_exit old KAR file found \'$NEW_KAR_FILE\'
+            dpec__ 106; err_exit old $MSS file found \'$F2R\'
         fi
     fi
+}
+
+kar_new ()
+{
+    check_force_remove_old_kar $NEW_KAR_FILE KAR
+    check_force_remove_old_kar $NEW_CACHE_FILE .VDBCACHE
 
     TCMD="$KAR_BIN"
     if [ -n "$FORCE_VAL" ]
@@ -1319,7 +1343,20 @@ kar_new ()
 
     dpec__ 62; exec_cmd_exit $TCMD
 
-    test_kar $NEW_KAR_FILE
+    if [ -d "$DATABASE_CACHE_DIR" ]
+    then
+        info_msg "Creating .VDBCACHE file"
+
+        TCMD="$KAR_BIN"
+        if [ -n "$FORCE_VAL" ]
+        then
+            TCMD="$TCMD -f"
+        fi
+
+        TCMD="$TCMD --create $NEW_CACHE_FILE --directory $DATABASE_CACHE_DIR"
+
+        dpec__ 62; exec_cmd_exit $TCMD
+    fi
 }
 
 print_stats ()
@@ -1364,12 +1401,86 @@ export_proc ()
     ## writing delited kar archive
     kar_new
 
+
+    if [ -n "$SKIPTEST_VAL" ]
+    then
+        warn_msg skipping tests for \'$NEW_KAR_FILE\' ...
+        return
+    else
+        test_kar
+    fi
+
     ## just printing stats
     print_stats
 
     info_msg "DONE"
 }
 
+###############################################################################################
+###############################################################################################
+###<<>>### Test
+##############################################################################################
+check_ready_for_test ()
+{
+    if [ ! -f "$STATUS_FILE" ]
+    then
+        dpec__ 105; err_exit can not stat status file
+    fi
+
+    TVAR=`grep "$DELITED_TAG" $STATUS_FILE 2>/dev/null`
+    if [ -z "$TVAR" ]
+    then
+        dpec__ 86; err_exit status shows that object was not delited yet
+    fi
+
+    if [ ! -e "$ORIG_KAR_FILE" ]
+    then
+        dpec__ 105; err_exit can not stat original KAR file \'$ORIG_KAR_FILE\'
+    fi
+
+    if [ ! -f "$NEW_KAR_FILE" ]
+    then
+        dpec__ 105; err_exit can not stat delited KAR file \'$NEW_KAR_FILE\'
+    fi
+
+    TVAR=`$KARMETA_BIN --info SOFTWARE/delite $NEW_KAR_FILE 2>/dev/null`
+    if [ -z "$TVAR" ]
+    then
+        dpec__ 86; err_exit object was not delited yet
+    fi
+
+    if [ -h "$ORIG_CACHE_FILE" ]
+    then
+        if [ ! -e "$ORIG_CACHE_FILE" ]
+        then
+            dpec__ 105; err_exit can not stat .VDBCACHE for delited KAR file \'$ORIG_CACHE_FILE\'
+        fi
+
+        if [ ! -f "$NEW_CACHE_FILE" ]
+        then
+            dpec__ 105; err_exit can not stat .VDBCACHE for delited KAR file \'$NEW_CACHE_FILE\'
+        fi
+    fi
+}
+
+test_proc ()
+{
+    ## checking if it is was delited
+    check_ready_for_test
+
+    info_msg Changing directory to \'$TARGET_DIR\'
+    cd $TARGET_DIR
+
+    if [ ! -f "$VDBCFG_NAME" ]
+    then
+        dpec__ 105; err_exit can not stat file \'$VDBCFG_FILE\'
+    fi
+
+    test_kar
+
+    info_msg "DONE"
+}
+
 ###############################################################################################
 ###############################################################################################
 ###<<>>### Status
