@@ -29,10 +29,10 @@
 #include "helper.h"
 #include "line_iter.h"
 
-#include <vfs/resolver.h>
-#include <vfs/services.h> /* KServiceMake */
-#include <vfs/path.h>
 #include <vfs/manager.h>
+#include <vfs/path.h>
+#include <vfs/resolver-priv.h> /* VResolverGetProject */
+#include <vfs/services.h> /* KServiceMake */
 
 #include <kfs/directory.h>
 #include <kapp/main.h>
@@ -52,6 +52,9 @@
 #define PATH_MAX 4096
 #endif
 
+#define RELEASE(type, obj) do { rc_t rc2 = type##Release(obj); \
+    if (rc2 && !rc) { rc = rc2; } obj = NULL; } while (false)
+
 #define DEF_PROTO "https"
 
 static const char * proto_usage[]
@@ -63,6 +66,10 @@ static const char * cache_usage[] = { "resolve cache location along with remote"
                                       " when performing names function", NULL };
 #define ALIAS_CACHE   "c"
 
+static const char * cart_usage[] = { "PATH to jwt cart file", NULL };
+#define OPTION_CART   "perm"
+#define ALIAS_CART    NULL
+
 static const char * prj_usage[]
  = { "use numeric [dbGaP] project-id in names-cgi-call", NULL };
 #define ALIAS_PRJ    "d"
@@ -78,6 +85,14 @@ static const char * func_usage[] = { "function to perform "
 #define OPTION_FUNC   "function"
 #define ALIAS_FUNC    "f"
 
+static const char * locn_usage[] = { "location of data", NULL };
+#define OPTION_LOCN   "location"
+#define ALIAS_LOCN    NULL
+
+static const char * ngc_usage[] = { "PATH to ngc file", NULL };
+#define OPTION_NGC   "ngc"
+#define ALIAS_NGC     NULL
+
 static const char * path_usage[]
  = { "print path of object: names function-only", NULL };
 #define OPTION_PATH   "path"
@@ -90,6 +105,9 @@ static const char * param_usage[]
 static const char * raw_usage[] = { "print the raw reply (instead of parsing it)", NULL };
 #define ALIAS_RAW     "r"
 
+static const char * json_usage[] = { "print the reply in JSON", NULL };
+#define ALIAS_JSON    "j"
+
 static const char * timeout_usage[] = { "timeout-value for request", NULL };
 #define OPTION_TIMEOUT "timeout"
 #define ALIAS_TIMEOUT "t"
@@ -101,15 +119,19 @@ static const char * url_usage[] = { "url to be used for cgi-calls", NULL };
 OptDef ToolOptions[] =
 {                                                    /* needs_value, required */
     { OPTION_FUNC   , ALIAS_FUNC   , NULL, func_usage   ,   1,  true,   false },
+    { OPTION_LOCN   , ALIAS_LOCN   , NULL, locn_usage   ,   1,  true,   false },
     { OPTION_TIMEOUT, ALIAS_TIMEOUT, NULL, timeout_usage,   1,  true,   false },
     { OPTION_PROTO  , ALIAS_PROTO  , NULL, proto_usage  ,   1,  true,   false },
     { OPTION_VERS   , ALIAS_VERS   , NULL, vers_usage   ,   1,  true,   false },
     { OPTION_URL    , ALIAS_URL    , NULL, url_usage    ,   1,  true,   false },
     { OPTION_PARAM  , ALIAS_PARAM  , NULL, param_usage  ,  10,  true,   false },
     { OPTION_RAW    , ALIAS_RAW    , NULL, raw_usage    ,   1,  false,  false },
-    { OPTION_PRJ    , ALIAS_PRJ    , NULL, prj_usage    ,  10,  true  , false },
+    { OPTION_JSON   , ALIAS_JSON   , NULL, json_usage   ,   1,  false,  false },
+    { OPTION_PRJ    , ALIAS_PRJ    , NULL, prj_usage    ,  10,  true ,  false },
     { OPTION_CACHE  , ALIAS_CACHE  , NULL, cache_usage  ,   1,  false,  false },
     { OPTION_PATH   , ALIAS_PATH   , NULL, path_usage   ,   1,  false,  false },
+    { OPTION_CART   , ALIAS_CART   , NULL, cart_usage   ,   1,  true ,  false },
+    { OPTION_NGC    , ALIAS_NGC    , NULL, ngc_usage    ,   1,  true ,  false },
 };
 
 const char UsageDefaultName[] = "srapath";
@@ -160,8 +182,20 @@ rc_t CC Usage( const Args *args )
 
     OUTMSG(( "Options:\n" ));
 
-    for ( idx = 0; idx < count; ++idx ) /* start with 1, do not advertize row-range-option*/
-        HelpOptionLine( ToolOptions[ idx ].aliases, ToolOptions[ idx ].name, NULL, ToolOptions[ idx ].help );
+    for ( idx = 0; idx < count; ++idx ) {
+        /* start with 1, do not advertize row-range-option*/
+        const char * param = NULL;
+        if (ToolOptions[idx].aliases == NULL) {
+            if (strcmp(ToolOptions[idx].name, OPTION_NGC) == 0 ||
+                strcmp(ToolOptions[idx].name, OPTION_CART) == 0)
+            {
+                param = "PATH";
+            }
+        }
+
+        HelpOptionLine( ToolOptions[ idx ].aliases, ToolOptions[ idx ].name,
+            param, ToolOptions[ idx ].help );
+        }
 
     OUTMSG(( "\n" ));
     HelpOptionsStandard();
@@ -170,19 +204,83 @@ rc_t CC Usage( const Args *args )
     return rc;
 }
 
+static rc_t KSrvRespFile_Print(const KSrvRespFile * self) {
+    const VPath * path = NULL;
+    const VPath * vdbcache = NULL;
+    const String * tmp = NULL;
 
-static rc_t resolve_one_argument( VFSManager * mgr, VResolver * resolver, const char * pc )
+    rc_t rc = KSrvRespFileGetLocal(self, &path);
+    if (rc != 0) {
+        KSrvRespFileIterator * fi = NULL;
+        rc = KSrvRespFileMakeIterator(self, &fi);
+        if (rc == 0)
+            rc = KSrvRespFileIteratorNextPath(fi, &path);
+        RELEASE(KSrvRespFileIterator, fi);
+    }
+
+    if (path != NULL) {
+        rc = VPathMakeString(path, &tmp);
+        if (rc == 0) {
+            OUTMSG(("%S\n", tmp));
+            free((void *)tmp);
+        }
+        RELEASE(VPath, path);
+    }
+
+    if (vdbcache != NULL) {
+        rc = VPathMakeString(vdbcache, &tmp);
+        if (rc == 0) {
+            OUTMSG(("%S\n", tmp));
+            free((void *)tmp);
+        }
+        RELEASE(VPath, vdbcache);
+    }
+
+    return rc;
+}
+
+static rc_t resolve_one_argument( VFSManager * mgr, VResolver * resolver,
+    const char * pc, const char * location,
+    const char * cart, const char * ngc )
 {
     bool found = true;
     rc_t rc = 0;
 
-    uint32_t s = string_measure ( pc, NULL );
-    if ( s > 2 && ( pc [ 2 ] == 'P' || pc [ 2 ] == 'X' ) ) { /* SRP or SRX */
-        KService * service = NULL;
+/*  uint32_t s = string_measure ( pc, NULL ); */
+    if ( true ) { /* s > 2 && ( pc [ 2 ] == 'P' || pc [ 2 ] == 'X' ) ) { SRP or SRX */
         found = false;
+
+        KService * service = NULL;
         rc = KServiceMake ( & service );
-        if ( rc == 0 )
-            rc = KServiceAddId ( service, pc );
+        if ( rc == 0 ) {
+            if ( pc != NULL )
+                rc = KServiceAddId ( service, pc );
+            else if (cart != NULL) {
+                rc = KServiceSetJwtKartFile(service, cart);
+                if (rc != 0)
+                    PLOGERR(klogErr, (klogErr, rc,
+                        "cannot use '$(perm)' as jwt cart file",
+                        "perm=%s", cart));
+            }
+            else
+                rc = RC(rcExe, rcArgv, rcParsing, rcParam, rcInsufficient);
+        }
+        if (rc == 0 && location != NULL)
+            rc = KServiceSetLocation(service, location);
+        if (rc == 0) {
+            uint32_t project = 0;
+            rc = VResolverGetProject(resolver, &project);
+            if (rc == 0 && project != 0)
+                rc = KServiceAddProject(service, project);
+            if (rc == 0 && ngc != NULL) {
+                rc = KServiceSetNgcFile(service, ngc);
+                if (rc != 0)
+                    PLOGERR(klogErr, (klogErr, rc,
+                        "cannot use '$(ngc)' as ngc file",
+                        "ngc=%s", ngc));
+            }
+        }
+
         if ( rc == 0 ) {
             VRemoteProtocols protocol = eProtocolHttps;
             const KSrvResponse * response = NULL;
@@ -192,30 +290,25 @@ static rc_t resolve_one_argument( VFSManager * mgr, VResolver * resolver, const
                 uint32_t l = KSrvResponseLength  ( response );
                 found = true;
                 for ( i = 0; i < l && rc == 0; ++ i ) {
-                    const VPath * path = NULL;
-                    const VPath * vdbcache = NULL;
-                    rc = KSrvResponseGetLocal ( response, i, & path );
-                    if ( rc != 0 )
-                        rc = KSrvResponseGetPath ( response, i, protocol,
-                            & path, & vdbcache, NULL );
-                    if ( path != NULL ) {
-                        const String * tmp = NULL;
-                        rc = VPathMakeString ( path, & tmp );
-                        if ( rc == 0 ) {
-                            OUTMSG ( ( "%S\n", tmp ) );
-                            free ( ( void * ) tmp );
-                        }
-                        VPathRelease ( path );
-                    }
-                    if ( vdbcache != NULL ) {
-                        const String * tmp = NULL;
-                        rc = VPathMakeString ( vdbcache, & tmp );
-                        if ( rc == 0 ) {
-                            OUTMSG ( ( "%S\n", tmp ) );
-                            free ( ( void * ) tmp );
-                        }
-                        VPathRelease ( vdbcache );
+                    const KSrvRespObj * obj = NULL;
+                    KSrvRespObjIterator * it = NULL;
+                    KSrvRespFile * file = NULL;
+                    ESrvFileFormat type = eSFFInvalid;
+                    rc = KSrvResponseGetObjByIdx ( response, i, & obj );
+                    if ( rc == 0 )
+                        rc = KSrvRespObjMakeIterator ( obj, & it );
+                    while ( rc == 0 ) {
+                        rc_t r2 = 0;
+                        rc = KSrvRespObjIteratorNextFile ( it, & file );
+                        if ( rc != 0 || file == NULL )
+                            break;
+                        r2 = KSrvRespFileGetFormat(file, &type);
+                        if (r2 != 0 || type != eSFFVdbcache)
+                            rc = KSrvRespFile_Print(file);
+                        RELEASE ( KSrvRespFile, file );
                     }
+                    RELEASE ( KSrvRespObjIterator, it );
+                    RELEASE ( KSrvRespObj, obj );
                 }
                 KSrvResponseRelease ( response );
             }
@@ -315,12 +408,21 @@ static rc_t resolve_one_argument( VFSManager * mgr, VResolver * resolver, const
 static rc_t resolve_arguments( Args * args )
 {
     uint32_t acount;
-    rc_t rc = ArgsParamCount( args, &acount );
+    rc_t rc = 0;
+
+    uint32_t idx = 0;
+    const char * cart = NULL;
+    rc = ArgsOptionCount(args, OPTION_CART, &idx);
+    if (rc == 0 && idx > 0)
+        rc = ArgsOptionValue(args, OPTION_CART, 0, (const void**)&cart);
+
+    if (rc == 0)
+        rc = ArgsParamCount(args, &acount);
     if ( rc != 0 )
         LOGERR ( klogInt, rc, "failed to count parameters" );
-    else if ( acount < 1 )
+    else if ( acount < 1 && cart == NULL )
     {
-        /* That useless: rc = */ MiniUsage( args );
+        MiniUsage( args );
         rc = RC( rcExe, rcArgv, rcParsing, rcParam, rcInsufficient );
     }
     else
@@ -337,7 +439,10 @@ static rc_t resolve_arguments( Args * args )
                 LOGERR ( klogErr, rc, "failed to get VResolver object" );
             else
             {
-                uint32_t idx;
+                rc_t r2 = 0;
+
+                const char * location = get_str_option(args, OPTION_LOCN, NULL);
+                const char * ngc = get_str_option(args, OPTION_NGC, NULL);
 
                 rc = ArgsOptionCount ( args, OPTION_PROTO, & idx );
                 if ( rc == 0 && idx == 0 )
@@ -362,9 +467,22 @@ static rc_t resolve_arguments( Args * args )
                     rc = ArgsParamValue( args, idx, ( const void ** )&pc );
                     if ( rc != 0 )
                         LOGERR( klogInt, rc, "failed to retrieve parameter value" );
-                    else
-                        rc = resolve_one_argument( mgr, resolver, pc );
+                    else {
+                        rc_t rx = resolve_one_argument(
+                            mgr, resolver, pc, location, NULL, ngc );
+                        if ( rx != 0 && r2 == 0)
+                            r2 = rx;
+                    }
                 }
+                if (cart != NULL) {
+                    rc_t rx = resolve_one_argument(
+                        mgr, resolver, NULL, location, cart, ngc);
+                    if (rx != 0 && r2 == 0)
+                        r2 = rx;
+                }
+
+                if (r2 != 0 && rc == 0)
+                    rc = r2;
                 VResolverRelease( resolver );
             }
             VFSManagerRelease( mgr );
@@ -383,7 +501,7 @@ static rc_t on_reply_line( const String * line, void * data )
 
 typedef struct out_fmt
 {
-    bool raw, cache, path;
+    bool raw, cache, path, json;
 } out_fmt;
 
 
@@ -411,6 +529,7 @@ static rc_t prepare_request( const Args * args, request_params * r, out_fmt * fm
             r->names_url  = get_str_option( args, OPTION_URL, NULL );
             r->names_ver  = get_str_option( args, OPTION_VERS, NULL );
             r->proto      = get_str_option( args, OPTION_PROTO, DEF_PROTO );
+            r->location   = get_str_option( args, OPTION_LOCN, NULL );
             r->search_url = NULL;
             r->search_ver = NULL;
             
@@ -443,6 +562,9 @@ static rc_t prepare_request( const Args * args, request_params * r, out_fmt * fm
     }
 
     fmt->raw = get_bool_option( args, OPTION_RAW );
+    fmt->json = get_bool_option( args, OPTION_JSON );
+    r->cart = get_str_option(args, OPTION_CART, NULL);
+    r->ngc = get_str_option(args, OPTION_NGC, NULL);
 
     return rc;
 }
@@ -473,6 +595,9 @@ static rc_t names_cgi( const Args * args )
                    "' is ignored with '--" OPTION_RAW "'" );
             rc = raw_names_request( &r, on_reply_line, &rslt_code, NULL );
         }
+        else if (fmt.json) {
+            rc = names_request_json ( & r, fmt . cache, fmt . path );
+        }
         else
             rc = names_request ( & r, fmt . cache, fmt . path );
     
