@@ -55,6 +55,8 @@
 #include <kapp/args.h>
 #include <kapp/main.h>
 
+#include <kfg/config.h> /* KConfigSetNgcFile */
+
 #include <assert.h>
 #include <string.h>
 #include <stdint.h>
@@ -87,6 +89,8 @@ KKey Key;
 const char * ForceUsage[] = 
 { "Force overwrite of existing files", NULL };
 
+const char * NgcUsage[] = { "PATH to ngc file", NULL };
+
 /*
  * option  control flags
  */
@@ -168,6 +172,8 @@ rc_t CC Usage (const Args * args)
     KOutMsg ("\nOptions:\n");
     HelpOptionLine (ALIAS_FORCE, OPTION_FORCE, NULL, ForceUsage);
     CryptOptionLines ();
+    HelpOptionLine(ALIAS_NGC, OPTION_NGC, "PATH", NgcUsage);
+    KOutMsg("\n");
     HelpOptionsStandard ();
 
     /* forcing editor alignment */
@@ -226,7 +232,7 @@ rc_t CC Usage (const Args * args)
         "  The encryption key or file password is handled by configuration. If not yet\n"
         "  set, this program will fail.\n\n"
         "  Please consult configuration page at\n"
-        "  https://www.ncbi.nlm.nih.gov/Traces/sra/sra.cgi?view=toolkit_doc&f=std or\n"
+        "  https://trace.ncbi.nlm.nih.gov/Traces/sra/sra.cgi?view=toolkit_doc&f=std or\n"
         "  https://github.com/ncbi/sra-tools/wiki/Toolkit-Configuration\n"        
         );
 
@@ -1260,6 +1266,24 @@ rc_t CommonMain (Args * args)
                                 "destination parameter");
                 }
 
+/* OPTION_NGC */
+                if (rc == 0) {
+                    const char * dummy = NULL;
+                    rc = ArgsOptionCount(args, OPTION_NGC, &pcount);
+                    if (rc != 0)
+                        LOGERR(klogErr, rc,
+                            "Failure to get '" OPTION_NGC "' argument");
+                    else if (pcount != 0) {
+                        rc = ArgsOptionValue(args, OPTION_NGC, 0,
+                            (const void **)&dummy);
+                        if (rc != 0)
+                            LOGERR(klogErr, rc,
+                                "Failure to get '" OPTION_NGC "' argument");
+                        else
+                            KConfigSetNgcFile(dummy);
+                    }
+                }
+
                 if (rc == 0)
                     rc = StartFileSystem (src, dst);
             }
